==> protobuf-maven-plugin-4.0.3-sources.jar: io/github/ascopes/protobufmavenplugin/plugins/UriProtocPlugin.java <==
/*
 * Copyright (C) 2023 - 2025, Ashley Scopes.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.github.ascopes.protobufmavenplugin.plugins;

import io.github.ascopes.protobufmavenplugin.digests.Digest;
import java.net.URI;
import java.util.Optional;
import org.immutables.value.Value.Modifiable;
import org.jspecify.annotations.Nullable;


/**
 * Implementation independent descriptor for a protoc plugin that can be resolved from a URI.
 *
 * <p>URI-based plugins can be marked as optional if they should be skipped when the resource
 * is unable to be resolved.
 *
 * @author Ashley Scopes
 * @since 2.0.0
 */
@Modifiable
public abstract class UriProtocPlugin implements OptionalProtocPlugin {

  public abstract URI getUrl();

  public abstract @Nullable Digest getDigest();

  @Override
  public String toString() {
    var sb = new StringBuilder()
        .append(getUrl());

    Optional.ofNullable(getDigest())
        .map(Digest::toString)
        .map("#digest="::concat)
        .ifPresent(sb::append);

    return sb.toString();
  }
}

==> protobuf-maven-plugin-4.1.1-sources.jar: io/github/ascopes/protobufmavenplugin/plugins/UriProtocPlugin.java <==
/*
 * Copyright (C) 2023 - 2025, Ashley Scopes.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.github.ascopes.protobufmavenplugin.plugins;

import io.github.ascopes.protobufmavenplugin.digests.Digest;
import io.github.ascopes.protobufmavenplugin.plexus.KindHint;
import java.net.URI;
import java.util.Optional;
import org.immutables.value.Value.Default;
import org.immutables.value.Value.Modifiable;
import org.jspecify.annotations.Nullable;


/**
 * Implementation independent descriptor for a protoc plugin that can be resolved from a URI.
 *
 * <p>URI-based plugins can be marked as optional if they should be skipped when the resource
 * is unable to be resolved.
 *
 * @author Ashley Scopes
 * @since 2.0.0
 */
@Modifiable
@KindHint(kind = "url", implementation = UriProtocPluginBean.class)
public abstract non-sealed class UriProtocPlugin implements ProtocPlugin {

  public abstract @Nullable Digest getDigest();

  public abstract URI getUrl();

  @Default.Boolean(false)
  public abstract boolean isOptional();

  @Override
  public String toString() {
    var sb = new StringBuilder()
        .append(getUrl());

    Optional.ofNullable(getDigest())
        .map(Digest::toString)
        .map("#digest="::concat)
        .ifPresent(sb::append);

    return sb.toString();
  }
}
